[**Opzioni avanzate**](./introduction.md) > **Codice lingua** _(current)_

---

#### Google

Fonte <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, organizzato da GPT-4o.

| Etichetta in cinese | Etichetta | `Codice lingua` |
| --- | --- | --- |
| Amarico | Amharic | `am` |
| 阿拉伯语 | Arabic | `ar` |
| 巴斯克语 | Basque | `eu` |
| 孟加拉语 | Bengali | `bn` |
| Inglese (Regno Unito) | English (UK) | `en-GB` |
| Portoghese (Brasile) | Portuguese (Brazil) | `pt-BR` |
| Bulgaro | Bulgarian | `bg` |
| Catalano | Catalan | `ca` |
| 切罗基语 | Cherokee | `chr` |
| Croato | Croatian | `hr` |
| 捷克语 | Czech | `cs` |
| 丹麦语 | Danish | `da` |
| 荷兰语 | Dutch | `nl` |
| Inglese (Stati Uniti) | English (US) | `en` |
| 爱沙尼亚语 | Estonian | `et` |
| 菲律宾语 | Filipino | `fil` |
| 芬兰语 | Finnish | `fi` |
| 法语 | French | `fr` |
| 德语 | German | `de` |
| 希腊语 | Greek | `el` |
| 古吉拉特语 | Gujarati | `gu` |
| 希伯来语 | Hebrew | `iw` |
| 印地语 | Hindi | `hi` |
| 匈牙利语 | Hungarian | `hu` |
| 冰岛语 | Icelandic | `is` |
| Indonesiano | Indonesian | `id` |
| Italiano | Italian | `it` |
| 日语 | Japanese | `ja` |
| 卡纳达语 | Kannada | `kn` |
| 韩语 | Korean | `ko` |
| 拉脱维亚语 | Latvian | `lv` |
| Lituano | Lithuanian | `lt` |
| 马来语 | Malay | `ms` |
| 马拉雅拉姆语 | Malayalam | `ml` |
| 马拉地语 | Marathi | `mr` |
| 挪威语 | Norwegian | `no` |
| Polacco | Polish | `pl` |
| Portoghese (Portogallo) | Portuguese (Portugal) | `pt-PT` |
| Rumeno | Romanian | `ro` |
| Russo | Russian | `ru` |
| 塞尔维亚语 | Serbian | `sr` |
| 中文（中国） | Chinese (PRC) | `zh-CN` |
| Slovacco | Slovak | `sk` |
| Sloveno | Slovenian | `sl` |
| 西班牙语 | Spanish | `es` |
| 斯瓦希里语 | Swahili | `sw` |
| 瑞典语 | Swedish | `sv` |
| 泰米尔语 | Tamil | `ta` |
| 泰卢固语 | Telugu | `te` |
| 泰语 | Thai | `th` |
| 中文（台湾） | Chinese (Taiwan) | `zh-TW` |
| 土耳其语 | Turkish | `tr` |
| 乌尔都语 | Urdu | `ur` |
| Ucraino | Ukrainian | `uk` |
| Vietnamita | Vietnamese | `vi` |
| Gallese | Welsh | `cy` |


#### DeepL
Fonte <https://developers.deepl.com/docs/resources/supported-languages>, organizzato da GPT-4o.

| Etichetta in cinese | Etichetta | `Codice lingua`| Supporta |
| --- | --- | --- | --- |
| Arabo | Arabic | `AR` | `source`, `target` |
| Bulgaro | Bulgarian | `BG` | `source`, `target` |
| 捷克语 | Czech | `CS` | `source`, `target` |
| Danese | Danish | `DA` | `source`, `target` |
| 德语 | German | `DE` | `source`, `target` |
| 希腊语 | Greek | `EL` | `source`, `target` |
| 英语 | English | `EN` | `source`, `target` |
| Inglese (Regno Unito) | English (British) | `EN-GB` | `target` |
| Inglese (Stati Uniti) | English (American) | `EN-US` | `target` |
| Spagnolo | Spanish | `ES` | `source`, `target` |
| 爱沙尼亚语 | Estonian | `ET` | `source`, `target` |
| 芬兰语 | Finnish | `FI` | `source`, `target` |
| Francese | French | `FR` | `source`, `target` |
| 匈牙利语 | Hungarian | `HU` | `source`, `target` |
| Indonesiano | Indonesian | `ID` | `source`, `target` |
| Italiano | Italian | `IT` | `source`, `target` |
| 日语 | Japanese | `JA` | `source`, `target` |
| Coreano | Korean | `KO` | `source`, `target` |
| 立陶宛语 | Lithuanian | `LT` | `source`, `target` |
| 拉脱维亚语 | Latvian | `LV` | `source`, `target` |
| Norvegese Bokmål | Norwegian Bokmål | `NB` | `source`, `target` |
| 荷兰语 | Dutch | `NL` | `source`, `target` |
| Polacco | Polish | `PL` | `source`, `target` |
| Portoghese | Portuguese | `PT` | `source`, `target` |
| Portoghese (Brasile) | Portuguese (Brazilian) | `PT-BR` | `target` |
| Portoghese (Europeo) | Portuguese (European) | `PT-PT` | `target` |
| 罗马尼亚语 | Romanian | `RO` | `source`, `target` |
| 俄语 | Russian | `RU` | `source`, `target` |
| Slovacco | Slovak | `SK` | `source`, `target` |
| Sloveno | Slovenian | `SL` | `source`, `target` |
| Svedese | Swedish | `SV` | `source`, `target` |
| 土耳其语 | Turkish | `TR` | `source`, `target` |
| 乌克兰语 | Ukrainian | `UK` | `source`, `target` |
| Italiano | Italian | `IT` | `source`, `target` |
| 中文（简体） | Chinese (Simplified) | `ZH-HANS` | `target` |
| 中文（繁体） | Chinese (Traditional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>Parte del contenuto di questa pagina è stata tradotta da GPT e potrebbe contenere errori.</small></h6>